@@ -335,25 +335,49 @@ def pgpConn():
 #-----------------------------END PGP--------------------------------
 
 #-----------------------------MT--------------------------------
+def mtConn(): # here we convert the result of the command 'getblockcount' on a random art design
+    while True:
+        try:
+            clear()
+            close()
+            mtclock()
+        except:
+            break
 
-def mtConn():
-    try:
-        conn = """curl -s https://bitcoinexplorer.org/api/price/usd/sats"""
-        a = os.popen(conn).read()
-        clear()
-        blogo()
-        closed()
-        output = render(
-            "Moscow Time", colors=['yellow'], align='left', font='tiny'
-        )
-        outputT = render(
-            a + " sats", colors=['green'], align='left', font='tiny'
-        )
-        print(output)
-        print(outputT)
-        input("\a\nContinue...")
-    except:
-        pass
+def mtclock():
+    if os.path.isfile('config/pyblocksettingsClock.conf') or os.path.isfile('config/pyblocksettingsClock.conf'): # Check if the file 'bclock.conf' is in the same folder
+        settingsv = pickle.load(open("config/pyblocksettingsClock.conf", "rb")) # Load the file 'bclock.conf'
+        settingsClock = settingsv # Copy the variable pathv to 'path'
+    else:
+        settingsClock = {"gradient":"", "design":"block", "colorA":"green", "colorB":"yellow"}
+        pickle.dump(settingsClock, open("config/pyblocksettingsClock.conf", "wb"))
+    clear()
+    r = requests.get('https://bitcoinexplorer.org/api/price/usd/sats')
+    r.headers['Content-Type']
+    n = r.text
+    di = json.loads(n)
+    a = di
+    b = str(a)
+    clear()
+    close()
+    output = render(str(a), colors=[settingsClock['colorA'], settingsClock['colorB']], align='center')
+    print("\033[0;37;40m\x1b[?25l" + output)
+    while True:
+        x = b
+        r = requests.get('https://bitcoinexplorer.org/api/price/usd/sats')
+        r.headers['Content-Type']
+        n = r.text
+        di = json.loads(n)
+        a = di
+        if x < str(a):
+            clear()
+            close()
+            output5 = subprocess.check_output(['sudo', 'iwgetid'])
+            z = str(output5)
+            pp = random.choice(list(faceshappy.values())).encode('utf-8').decode('latin-1')
+            output = render(str(a), colors=[settingsClock['colorA'], settingsClock['colorB']], align='center')
+            print("\033[0;37;40m\x1b[?25l" + output)
+            b = str(a)    #try:
 
 #-----------------------------END MT--------------------------------
 
@@ -963,11 +987,11 @@ def lnbitCreatePayWall():
             amt = input("Amount in sats: ")
             remb = input("Remembers Y/n: ")
             a = loadFileConnLNBits(['admin_key'])
-            b = str(a['admin_key'])
             if remb in ["Y", "y"]:
                 remember = "true"
             elif remb in ["N", "n"]:
                 remember = "false"
+            b = str(a['admin_key'])
             curl = (
                 'curl -X POST https://lnbits.com/paywall/api/v1/paywalls -d '
                 + "'{"
@@ -986,10 +1010,8 @@ def lnbitCreatePayWall():
             clear()
             aa = loadFileConnLNBits(['invoice_read_key'])
             bb = str(a['invoice_read_key'])
-            checkcurl = (
-                'curl -X GET https://lnbits.com/paywall/api/v1/paywalls -H'
-                + f""" "X-Api-Key: {bb}" """
-            )
+            checkcurl = f"""curl -X GET https://lnbits.com/paywall/api/v1/paywalls -H "X-Api-Key: {bb}" """
+
 
             sh = os.popen(checkcurl).read()
             clear()
@@ -1007,7 +1029,8 @@ def lnbitCreatePayWall():
                     nn = s['id']
                     if nd == nn:
                         print("\n----------------------------------------------------------------------------------------------------------------")
-                        print("""
+                        print(
+                            """
                         \tLNBITS PAYWALL DECODED
 
                         ID: {}
@@ -1018,7 +1041,18 @@ def lnbitCreatePayWall():
                         Remembers: {}
                         URL: {}
                         Wallet: {}
-                        """.format(s['id'], s['amount'], s['description'], s['memo'], s['extras'], s['remembers'], s['url'], s['wallet']))
+                        """.format(
+                                nn,
+                                s['amount'],
+                                s['description'],
+                                s['memo'],
+                                s['extras'],
+                                s['remembers'],
+                                s['url'],
+                                s['wallet'],
+                            )
+                        )
+
                         print("----------------------------------------------------------------------------------------------------------------\n")
                 input("Continue...")
             clear()
@@ -1387,9 +1421,9 @@ def lnpayGetTransactions():
             for transaction in transactions:
                 s = transaction
                 nn = s['id']
-                nnn = s['lnTx']
                 if nd == nn:
                     print("\n----------------------------------------------------------------------------------------------------")
+                    nnn = s['lnTx']
                     print("""
                     \tLNPAY LIST PAYMENT DECODED
 
@@ -1534,10 +1568,8 @@ def createFileConnOpenNode():
 def OpenNodelistfunds():
     a = loadFileConnOpenNode(['wdr'])
     b = str(a['wdr'])
-    curl = (
-        "curl https://api.opennode.co/v1/account/balance -H "
-        + f'"Content-Type: application/json" -H "Authorization: {b}"'
-    )
+    curl = f'curl https://api.opennode.co/v1/account/balance -H "Content-Type: application/json" -H "Authorization: {b}"'
+
 
     sh = os.popen(curl).read()
     clear()
@@ -1545,8 +1577,8 @@ def OpenNodelistfunds():
     n = str(sh)
     d = json.loads(n)
     r = d['data']
-    p = r['balance']
     print("\n----------------------------------------------------------------------------------------------------")
+    p = r['balance']
     print("""
     OPENNODE BALANCE
 
